@@ -14,6 +14,9 @@ FRAMEWORK = TEST_FRAMEWORK = "test.framework"
 # Test Name
 NAME = TEST_NAME = "test.name"
 
+# Pytest Result (XFail, XPass)
+RESULT = TEST_RESULT = "pytest.result"
+
 # Skip Reason
 SKIP_REASON = TEST_SKIP_REASON = "test.skip_reason"
 
@@ -29,8 +32,13 @@ TRAITS = TEST_TRAITS = "test.traits"
 # Test Type
 TYPE = TEST_TYPE = "test.type"
 
+# XFail Reason
+XFAIL_REASON = TEST_XFAIL_REASON = "pytest.xfail.reason"
+
 
 class Status(Enum):
     PASS = "pass"
     FAIL = "fail"
     SKIP = "skip"
+    XFAIL = "xfail"
+    XPASS = "xpass"
