@@ -1,6 +1,7 @@
 import socket
+from typing import Any
 
-from ..compat import httplib
+from .compat import httplib
 
 
 class UDSHTTPConnection(httplib.HTTPConnection):
@@ -8,14 +9,18 @@ class UDSHTTPConnection(httplib.HTTPConnection):
 
     # It's "important" to keep the hostname and port arguments here; while there are not used by the connection
     # mechanism, they are actually used as HTTP headers such as `Host`.
-    def __init__(self, path, https, *args, **kwargs):
-        if https:
-            httplib.HTTPSConnection.__init__(self, *args, **kwargs)
-        else:
-            httplib.HTTPConnection.__init__(self, *args, **kwargs)
+    def __init__(
+        self,
+        path,  # type: str
+        *args,  # type: Any
+        **kwargs  # type: Any
+    ):
+        # type: (...) -> None
+        httplib.HTTPConnection.__init__(self, *args, **kwargs)
         self.path = path
 
     def connect(self):
+        # type: () -> None
         sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         sock.connect(self.path)
         self.sock = sock
